toastr library

Classes

ToastrAction
Action button configuration for toasts.
ToastrConfig
Configuration class for toastr notifications.
ToastrHelper
Helper class with convenient methods for showing different types of toastrs.
ToastrIconTheme
Icon theme configuration for toast types.
ToastrSecurityConfig
Security limit configuration for toastr notifications.
ToastrService
Service to manage and display toastr notifications with stacking, queueing, lifecycle awareness, and security features.
ToastrValidator
Utility class for validating toastr configurations and inputs with security
ToastrWidget
Toast widget faithful to react-hot-toast styling.

Enums

HapticFeedbackType
Type of haptic feedback to trigger
SwipeDismissDirection
Direction in which a toast can be swiped to dismiss
ToastrHideMethod
Hide animation methods similar to original toastr
ToastrPosition
Defines where the toastr should appear on screen
ToastrShowMethod
Show animation methods similar to original toastr
ToastrTheme
Color theme for toast notifications
ToastrType
Defines the different types of toastr notifications available.

Typedefs

Toastr = ToastrHelper
Short alias for ToastrHelper — use like react-hot-toast's toast().