SwipeDismissDirection enum

Direction in which a toast can be swiped to dismiss

Inheritance
Available extensions

Values

horizontal → const SwipeDismissDirection

Swipe left or right to dismiss

vertical → const SwipeDismissDirection

Swipe up or down to dismiss

both → const SwipeDismissDirection

Swipe in any direction to dismiss

none → const SwipeDismissDirection

Disable swipe-to-dismiss

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SwipeDismissDirection>
A constant List of the values in this enum, in order of their declaration.